darkhistory.utilities.Interpolator2D — DarkHistory documentation

# darkhistory.utilities.Interpolator2D

class `darkhistory.utilities.` `Interpolator2D`(arr0, name0, arr1, name1, val_arr, logInterp=False)

  Interpolation function over a list of objects.

  Parameters: | val_arr : list of objects List of objects, `ndim = (arr0.size, arr1.size, ...)` arr0 : ndarray list of values along 0th dimension arr1 : ndarray list of values along 1st dimension
  Attributes: | interp_func : function A 2D interpolation function over `arr0` and `arr1`. _grid_vals : ndarray a nD array of input data

  Methods

  get_val |
  get_vals |

  `__init__`(arr0, name0, arr1, name1, val_arr, logInterp=False)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `__init__`(arr0, name0, arr1, name1, val_arr) | Initialize self.
  `get_val`(val0, val1) |
  `get_vals`(val0, vals1) |

#### Previous topic

darkhistory.utilities.spence_series_diff

#### Next topic

darkhistory.electrons

### This Page

Show Source